==> apache-cloudstack-4.19.3.0-src.tar.bz2: apache-cloudstack-4.19.3.0-src/plugins/network-elements/nicira-nvp/src/main/java/com/cloud/network/nicira/NiciraNvpTag.java <==
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.network.nicira;

import org.apache.log4j.Logger;

public class NiciraNvpTag {
    private static final int TAG_MAX_LEN = 40;
    private static final Logger s_logger = Logger.getLogger(NiciraNvpTag.class);
    private String scope;
    private String tag;

    public NiciraNvpTag() {
    }

    public NiciraNvpTag(String scope, String tag) {
        this.scope = scope;
        if (tag.length() > 40) {
            s_logger.warn("tag \"" + tag + "\" too long, truncating to 40 characters");
            this.tag = tag.substring(0, TAG_MAX_LEN);
        } else {
            this.tag = tag;
        }
    }

    public String getScope() {
        return scope;
    }

    public void setScope(String scope) {
        this.scope = scope;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        if (tag.length() > 40) {
            s_logger.warn("tag \"" + tag + "\" too long, truncating to 40 characters");
            this.tag = tag.substring(0, 40);
        } else {
            this.tag = tag;
        }
    }

}

==> apache-cloudstack-4.20.2.0-src.tar.bz2: apache-cloudstack-4.20.2.0-src/plugins/network-elements/nicira-nvp/src/main/java/com/cloud/network/nicira/NiciraNvpTag.java <==
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.network.nicira;

import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.LogManager;

public class NiciraNvpTag {
    private static final int TAG_MAX_LEN = 40;
    protected Logger logger = LogManager.getLogger(getClass());
    private String scope;
    private String tag;

    public NiciraNvpTag() {
    }

    public NiciraNvpTag(String scope, String tag) {
        this.scope = scope;
        if (tag.length() > 40) {
            logger.warn("tag \"" + tag + "\" too long, truncating to 40 characters");
            this.tag = tag.substring(0, TAG_MAX_LEN);
        } else {
            this.tag = tag;
        }
    }

    public String getScope() {
        return scope;
    }

    public void setScope(String scope) {
        this.scope = scope;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        if (tag.length() > 40) {
            logger.warn("tag \"" + tag + "\" too long, truncating to 40 characters");
            this.tag = tag.substring(0, 40);
        } else {
            this.tag = tag;
        }
    }

}
